@@ -30,6 +30,16 @@ def contact():
     return render_template("success.html", name="Contact")
 
 
+@app.route("/rel")
+def relative_link():
+    return render_template("success.html", name="Rel")
+
+
+@app.route("/rel2")
+def relative_link2():
+    return render_template("success.html", name="Rel2")
+
+
 @app.route("/login")
 def login():
     return render_template("error.html", status_code=401), 401
@@ -42,7 +52,7 @@ def five_hundred():
 
 @app.route("/sitemap.xml")
 def sitemap():
-    return render_template('sitemap.xml')
+    return render_template("sitemap.xml")
 
 
 if __name__ == "__main__":
